/**
 * External dependencies
 */
import { nanoid } from "nanoid";

/**
 * WordPress dependencies
 */
import { useEffect } from "@wordpress/element";

/**
 * Store ids
 */
const ids = {};

/**
 * Generate unique id
 *
 * @param {String} clientId
 * @param {String} id
 * @returns {String}
 */
const maybeUpdateId = (clientId, id) => {
  if (
    !id ||
    Object.keys(ids).find((keyId) => ids[keyId] === id && keyId !== clientId)
  ) {
    const newId = nanoid(10);
    ids[clientId] = newId;

    return newId;
  }

  return false;
};

/**
 * Set id for the block
 *
 * @param {String} clientId
 * @param {String} id
 */
const setId = (clientId, id) => {
  ids[clientId] = id;
};

export const useUniqueId = (
  id,
  clientId,
  onUpdateId,
  inNeedOfUniqueId = true
) => {
  useEffect(() => {
    if (inNeedOfUniqueId) {
      const newId = maybeUpdateId(clientId, id);
      if (newId) {
        onUpdateId(newId);
      }

      setId(clientId, newId ? newId : id);

      return () => {
        setId(clientId, null);
      };
    }
  }, [id, clientId, inNeedOfUniqueId]);

  return ids[clientId];
};
