/**
 * External dependencies
 */
import { isArray } from "lodash";

/**
 * WordPress dependencies
 */
import { __ } from "@wordpress/i18n";
import { useContext } from "@wordpress/element";

/**
 * Internal dependencies
 */
import { FeatureAllowedBlocksWidget } from "./feature-allowed-blocks";
import { DataContext } from "../utils";
import { Section } from "../../components";

// WithIcon widget.
export const SectionBlocksManager = () => {
  const {
    blockTypes,
    allowedBlocks,
    setAllowedBlocks,
    blockTypesByFeature,
    updateSettings,
    isLoading,
  } = useContext(DataContext);

  const widgetControls = Object.keys(blockTypesByFeature).map((featureName) => {
    const regExpPattern = new RegExp(
      (blockTypesByFeature[featureName]["availableBlocks"] ?? [])
        .map(({ name }) => name)
        .join("|")
    );

    const availableBlocks = blockTypes.filter(({ name }) => {
      const match = name.match(regExpPattern);
      return match && match[0] === name;
    });

    availableBlocks.sort(({ title: title1 }, { title: title2 }) => {
      if (title1 > title2) {
        return 1;
      } else if (title1 < title2) {
        return -1;
      }

      return 0;
    });

    const hasFeature = (allowedBlocks ?? []).find(
      (item) => item?.featureName === featureName
    );

    if (!hasFeature && isArray(allowedBlocks)) {
      allowedBlocks.push({
        featureName,
        allowedBlocks: blockTypesByFeature[featureName]?.allowedBlocks ?? [],
      });
    }

    const selectedBlocks =
      (allowedBlocks ?? []).find((item) => item?.featureName === featureName)
        ?.allowedBlocks ?? [];

    const setSelectedBlocks = (newBlocks, featureName) => {
      const newAllowedBlocks = (allowedBlocks ?? []).map((item) => {
        if (item?.featureName !== featureName) {
          return { ...item };
        } else {
          return { ...item, allowedBlocks: newBlocks };
        }
      });

      setAllowedBlocks(newAllowedBlocks);
    };

    return (
      <FeatureAllowedBlocksWidget
        isLoading={isLoading}
        title={`${__(
          "Choose allowed blocks for feature: ",
          "block-enhancements"
        )}"${featureName}"`}
        featureName={featureName}
        blockTypes={availableBlocks}
        selectedBlocks={selectedBlocks}
        setSelectedBlocks={setSelectedBlocks}
        updateSettings={updateSettings}
      />
    );
  });

  return (
    <Section
      title={__("Manage allowed blocks by features", "block-enhancements")}
    >
      {widgetControls}
    </Section>
  );
};
